/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2020  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QFrame>
#include <QGridLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QLineEdit>
#include <QPushButton>
#include <QSpacerItem>

#include "reportheaderdialog.h"

TReportHeaderDialog::TReportHeaderDialog(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QDialog(const_cast<QWidget*>(parent),flags)
{
	QFrame								*separator_hline;
	QGridLayout							*dialog_layout;
	QHBoxLayout							*button_hlayout;
	QLabel								*report_header1_label;
	QLabel								*report_header2_label;
	QPushButton							*accept_button;
	QPushButton							*cancel_button;
	QSpacerItem							*button_hspacer;
	QSpacerItem							*dialog_vspacer;


	this->resize(510,163);

	dialog_layout = new QGridLayout(this);

	report_header1_label = new QLabel(this);
	dialog_layout->addWidget(report_header1_label,0,0,1,1);

	d_report_header1_edit = new QLineEdit(this);
	dialog_layout->addWidget(d_report_header1_edit,0,1,1,1);

	report_header2_label = new QLabel(this);
	dialog_layout->addWidget(report_header2_label,1,0,1,1);

	d_report_header2_edit = new QLineEdit(this);
	dialog_layout->addWidget(d_report_header2_edit,1,1,1,1);

	separator_hline = new QFrame(this);
	separator_hline->setFrameShape(QFrame::HLine);
	separator_hline->setFrameShadow(QFrame::Sunken);
	dialog_layout->addWidget(separator_hline,2,0,1,2);

	dialog_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	dialog_layout->addItem(dialog_vspacer,3,0,1,2);

	button_hlayout = new QHBoxLayout();

	button_hspacer = new QSpacerItem(0,0,QSizePolicy::Expanding,QSizePolicy::Minimum);
	button_hlayout->addItem(button_hspacer);

	cancel_button = new QPushButton(this);
	cancel_button->setAutoDefault(false);
	button_hlayout->addWidget(cancel_button);

	accept_button = new QPushButton(this);
	accept_button->setAutoDefault(true);
	button_hlayout->addWidget(accept_button);
	dialog_layout->addLayout(button_hlayout,4,0,1,2);

	this->setWindowTitle(QStringLiteral("Report Header"));
	report_header1_label->setText(QStringLiteral("Header 1 Text:"));
	report_header2_label->setText(QStringLiteral("Header 2 Text:"));
	cancel_button->setText(QStringLiteral("Cancel"));
	accept_button->setText(QStringLiteral("Accept"));

	connect(accept_button,SIGNAL(clicked(void)),this,SLOT(accept(void)));
	connect(cancel_button,SIGNAL(clicked(void)),this,SLOT(reject(void)));
}

TReportHeaderDialog::~TReportHeaderDialog(void)
{
}

QString TReportHeaderDialog::Header1_Text(void) const
{
	return d_report_header1_edit->text();
}

QString TReportHeaderDialog::Header2_Text(void) const
{
	return d_report_header2_edit->text();
}

void TReportHeaderDialog::Set_Header1_Text(
	const QString						&text)
{
	d_report_header1_edit->setText(text);
}

void TReportHeaderDialog::Set_Header2_Text(
	const QString						&text)
{
	d_report_header2_edit->setText(text);
}




