/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2020  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef SETTINGSWIDGETHEADERFILE
#define SETTINGSWIDGETHEADERFILE

#include <QWidget>
#include <QColor>
#include <QSize>
#include <QIcon>

class QCheckBox;
class QLineEdit;
class QSlider;
class QToolButton;
class QComboBox;
class QResizeEvent;

class TSettingsWidget : public QWidget
{
Q_OBJECT

public:

// CREATORS
	TSettingsWidget(const QWidget *parent=0, Qt::WindowFlags flags=0);
	virtual ~TSettingsWidget(void);

// ACCESSORS
	int Label_Size(void) const;
	QColor Label_Color(void) const;
	bool Track_Label(void) const;
	QString Display_Format(void) const;
	int PDF_Orientation(void) const;
	int PDF_Resolution(void) const;

// MANIPULATORS
	void Set_Label_Size(const int);
	void Set_Label_Color(const QColor &color);
	void Set_Track_Label(const bool state);
	void Set_Display_Format(const QString &format);
	void Set_PDF_Orientation(const int orientation);	// 0 = portrait, 1 = landscape
	void Set_PDF_Resolution(const int resolution);		// 1-4

signals:
	void Label_Size_Changed(int);
	void Color_Changed(const QColor);
	void Item_Display_Format_Changed(const QString&);
	void Track_Item_Option_Changed(bool);

private slots:
	void Select_Color(void);
	void Display_Format_Updated(void);
	
protected:
	virtual void resizeEvent(QResizeEvent *event);

private:
	QComboBox							*d_pdf_orientation_combo;
	QComboBox							*d_pdf_resolution_combo;
	QCheckBox							*d_track_item_check;
	QLineEdit							*d_item_list_format_edit;
	QSlider								*d_item_size_slider;
	QToolButton							*d_color_select_button;
	
	QColor								d_current_color;
	bool								d_draw_on_resize;
	
	QIcon Create_Icon(const QSize &size,const QColor &color) const;

// NOT IMPLEMENTED
	TSettingsWidget(const TSettingsWidget&);
	TSettingsWidget& operator=(const TSettingsWidget&);
};

#endif
